=============================
:code:`Trakt['sync/watched']`
=============================

.. automodule:: trakt.interfaces.sync.watched

  .. autoclass:: SyncWatchedInterface
    :members: flags, get, movies, shows
    :undoc-members:
